colour_hdri.sampling Package — Colour - HDRI 0.1.0 documentation

# colour_hdri.sampling Package

## Sub-Modules

- colour_hdri.sampling.grossberg2003 Module
  - Grossberg (2003) Histogram Based Image Sampling

## Module Contents

`colour_hdri.sampling.` `samples_Grossberg2003`(image_stack, samples=1000, n=256)

  Returns the samples for given image stack intensity histograms using Grossberg (2003) method.

  Parameters: | image_stack (array_like) – Stack of single channel or multi-channel floating point images. samples (int, optional) – Samples count. n (int, optional) – Histograms bins count.
  Returns: | Intensity histograms samples.
  Return type: | ndarray